==> digikam-3.0.0-beta3.tar.bz2: digikam-3.0.0-beta3/extra/kipi-plugins/acquireimages/kipiplugin_acquireimages.desktop.cmake <==
[Desktop Entry]
Name=AcquireImages
Name[ast]=AcquireImages
Name[bg]=Сканиране на снимки
Name[bs]=Dohvatanje slika
Name[ca]=AcquireImages
Name[ca@valencia]=AcquireImages
Name[cs]=Získat obrázky
Name[da]=AcquireImages
Name[de]=Bilder scannen
Name[el]=Ανάκτηση εικόνων
Name[en_GB]=AcquireImages
Name[es]=AcquireImages
Name[et]=Pildihõive
Name[eu]=Eskuratu irudiak
Name[fi]=AcquireImages
Name[fr]=Acquisition d'images 
Name[ga]=AcquireImages
Name[gl]=AcquireImages
Name[he]=יבא-תמונות 
Name[hne]=एक्वायरइमेजेस
Name[hu]=Képek beolvasása
Name[is]=SkannaMyndir
Name[it]=Acquisizione di immagini
Name[ja]=AcquireImages
Name[km]=AcquireImages
Name[ko]=AcquireImages
Name[lv]=AcquireImages
Name[ms]=AcquireImages
Name[nb]=AcquireImages
Name[nds]=Biller rankriegen
Name[nl]=AfbeeldingenOphalen
Name[pa]=ਚਿੱਤਰ-ਲਵੋ
Name[pl]=PozyskajObrazy
Name[pt]=Aquisição de Imagens
Name[pt_BR]=Obter imagens
Name[ro]=Achiziție de imagini
Name[ru]=Сканирование изображений
Name[sk]=Získať obrázky
Name[sl]=AcquireImages
Name[sq]=Merr Imazhet
Name[sv]=Hämta bilder
Name[th]=นำเข้ารูปภาพ
Name[tr]=Resim Tara
Name[ug]=AcquireImages
Name[uk]=Отримання зображень
Name[x-test]=xxAcquireImagesxx
Name[zh_CN]=图像捕获
Name[zh_TW]=擷取影像
Comment=A tool to acquire images using flat scanner
Comment[ast]=Una ferramienta p'alquirir imáxenes emplegando un escáner planu
Comment[bg]=Инструмент за сканиране на снимки с плосък скенер
Comment[bs]=Alat za dohvatanje slika koristeći ravni skener
Comment[ca]=Una eina per capturar imatges des d'un escàner pla
Comment[ca@valencia]=Una eina per capturar imatges des d'un escàner pla
Comment[cs]=Nástroj pro získání obrázků pomocí plochého skeneru
Comment[da]=Et værktøj til at hente billeder med en scanner
Comment[de]=Ein Werkzeug, um Bilder mit einem Flachbettscanner zu scannen.
Comment[el]=Εργαλείο για την ανάκτηση εικόνων από έναν επιτραπέζιο σαρωτή
Comment[en_GB]=A tool to acquire images using flat scanner
Comment[es]=Una herramienta para adquirir imágenes usando un escáner
Comment[et]=Tööriist piltide hankimiseks skannerist
Comment[eu]=Eskaner laua erabiliz irudiak eskuratzeko tresna
Comment[fi]=Kuvien tuonti tasoskannerilta
Comment[fr]=Outil pour acquérir des images avec un scanner à plat
Comment[ga]=Uirlis a fhaigheann íomhánna ó scanóir cothrom
Comment[gl]=Unha ferramenta para adquirir imaxes mediante un escáner
Comment[he]=כלי ליבוא תמונות מסורק שטוח
Comment[hne]=फ्लेट स्केनर से फोटू प्राप्त करे के औजार
Comment[hu]=Egy eszköz képek beolvasására lapolvasóval
Comment[is]=Verkfæri til að skanna myndir með flatskanna
Comment[it]=Uno strumento per acquisire immagini usando uno scanner piatto
Comment[ja]=フラットスキャナを使って画像を取り込むツール
Comment[km]=ឧបករណ៍​សម្រាប់​ទទួល​យក​រូបភាព​ ដោយ​ប្រើ​ម៉ាស៊ីន​ស្កេន​​រាប​ស្មើ
Comment[lv]=Rīks attēlu iegūšanai no skenera
Comment[nb]=Et verktøy for å hente bilder ved hjelp av skanner
Comment[nds]=En Warktüüch för't Rankriegen vun Biller över en Inleser
Comment[nl]=Een hulpmiddel om afbeeldingen op te halen van een vlakke scanner
Comment[pa]=ਫਲੈਟ ਸਕੈਨਰ ਦੀ ਵਰਤੋਂ ਕਰਕੇ ਚਿੱਤਰ ਲੈਣ ਵਾਲਾ ਇੱਕ ਟੂਲ
Comment[pl]=Narzędzie do pozyskiwania obrazów przy wykorzystaniu płaskiego skanera
Comment[pt]=Uma ferramenta de aquisição de imagens com um 'scanner' plano
Comment[pt_BR]=Uma ferramenta para obter imagens usando um scanner de mesa
Comment[ro]=O unealtă de achiziționat imagini utilizînd un scaner plat
Comment[ru]=Инструмент для получения изображений с помощью сканера
Comment[sk]=Nástroj na získanie obrázkov zo skenera
Comment[sl]=Orodje za pridobivanje slik s pomočjo optičnega bralnika
Comment[sq]=Një mjet për të marrë imazhet duke përdorur një skaner me shtrat të sheshtë
Comment[sv]=Ett verktyg för att hämta bilder med en bildläsare
Comment[th]=เครื่องมือนำเข้ารูปภาพโดยใช้เครื่องสแกนภาพแบบตั้งโต๊ะ
Comment[tr]=Tarayıcı kullanarak resimleri elde etmek için bir araç
Comment[uk]=Інструмент для отримання зображень з планшетних сканерів
Comment[x-test]=xxA tool to acquire images using flat scannerxx
Comment[zh_CN]=一个使用扫描仪捕获图像的工具
Comment[zh_TW]=使用平台式掃描器擷取影像的工具
Icon=scanner
ServiceTypes=KIPI/Plugin
Type=Service
X-KDE-Library=kipiplugin_acquireimages
X-KIPI-PluginCategories=Import
X-KIPI-BinaryVersion=${KIPI_SO_VERSION}
author=Gilles Caulier, caulier dot gilles at gmail dot com

==> digikam-4.0.0-beta3.tar.bz2: digikam-4.0.0-beta3/extra/kipi-plugins/acquireimages/kipiplugin_acquireimages.desktop.cmake <==
[Desktop Entry]
UntranslatedGenericName=AcquireImages
Name=AcquireImages
Name[ast]=AcquireImages
Name[bg]=Сканиране на снимки
Name[bs]=Dohvatanje slika
Name[ca]=AcquireImages
Name[ca@valencia]=AcquireImages
Name[cs]=Získat obrázky
Name[da]=AcquireImages
Name[de]=Bilder scannen
Name[el]=Ανάκτηση εικόνων
Name[en_GB]=AcquireImages
Name[es]=Adquisición de imágenes
Name[et]=Pildihõive
Name[eu]=Eskuratu irudiak
Name[fi]=AcquireImages
Name[fr]=Acquisition d'images 
Name[ga]=AcquireImages
Name[gl]=AcquireImages
Name[he]=יבא-תמונות 
Name[hne]=एक्वायरइमेजेस
Name[hu]=Képek beolvasása
Name[is]=SkannaMyndir
Name[it]=Acquisizione di immagini
Name[ja]=AcquireImages
Name[km]=AcquireImages
Name[ko]=AcquireImages
Name[lv]=AcquireImages
Name[ms]=AcquireImages
Name[nb]=AcquireImages
Name[nds]=Biller rankriegen
Name[nl]=AfbeeldingenOphalen
Name[pa]=ਚਿੱਤਰ-ਲਵੋ
Name[pl]=Skanowanie obrazów
Name[pt]=Aquisição de Imagens
Name[pt_BR]=Obter imagens
Name[ro]=Achiziție de imagini
Name[ru]=Сканирование изображений
Name[sk]=Získať obrázky
Name[sl]=AcquireImages
Name[sq]=Merr Imazhet
Name[sv]=Hämta bilder
Name[th]=นำเข้ารูปภาพ
Name[tr]=Resim Tara
Name[ug]=AcquireImages
Name[uk]=Отримання зображень
Name[x-test]=xxAcquireImagesxx
Name[zh_CN]=图像捕获
Name[zh_TW]=擷取影像
Comment=A tool to acquire images using flat scanner
Comment[ast]=Una ferramienta p'alquirir imáxenes emplegando un escáner planu
Comment[bg]=Инструмент за сканиране на снимки с плосък скенер
Comment[bs]=Alat za dohvatanje slika koristeći ravni skener
Comment[ca]=Una eina per capturar imatges des d'un escàner pla
Comment[ca@valencia]=Una eina per capturar imatges des d'un escàner pla
Comment[cs]=Nástroj pro získání obrázků pomocí plochého skeneru
Comment[da]=Et værktøj til at hente billeder med en scanner
Comment[de]=Ein Werkzeug, um Bilder mit einem Flachbettscanner zu scannen.
Comment[el]=Εργαλείο για την ανάκτηση εικόνων από έναν επιτραπέζιο σαρωτή
Comment[en_GB]=A tool to acquire images using flat scanner
Comment[es]=Una herramienta para adquirir imágenes usando un escáner
Comment[et]=Tööriist piltide hankimiseks skannerist
Comment[eu]=Eskaner laua erabiliz irudiak eskuratzeko tresna
Comment[fi]=Kuvien tuonti tasoskannerilta
Comment[fr]=Outil pour acquérir des images avec un périphérique de numérisation à plat
Comment[ga]=Uirlis a fhaigheann íomhánna ó scanóir cothrom
Comment[gl]=Unha ferramenta para adquirir imaxes mediante un escáner
Comment[he]=כלי ליבוא תמונות מסורק שטוח
Comment[hne]=फ्लेट स्केनर से फोटू प्राप्त करे के औजार
Comment[hu]=Egy eszköz képek beolvasására lapolvasóval
Comment[is]=Verkfæri til að skanna myndir með flatskanna
Comment[it]=Uno strumento per acquisire immagini usando uno scanner piatto
Comment[ja]=フラットスキャナを使って画像を取り込むツール
Comment[km]=ឧបករណ៍​សម្រាប់​ទទួល​យក​រូបភាព​ ដោយ​ប្រើ​ម៉ាស៊ីន​ស្កេន​​រាប​ស្មើ
Comment[lt]=Įrankis gauti paveikslėlius naudojant plokščią skenerį
Comment[lv]=Rīks attēlu iegūšanai no skenera
Comment[nb]=Et verktøy for å hente bilder ved hjelp av skanner
Comment[nds]=En Warktüüch för't Rankriegen vun Biller över en Inleser
Comment[nl]=Een hulpmiddel om afbeeldingen op te halen van een vlakke scanner
Comment[pa]=ਫਲੈਟ ਸਕੈਨਰ ਦੀ ਵਰਤੋਂ ਕਰਕੇ ਚਿੱਤਰ ਲੈਣ ਵਾਲਾ ਇੱਕ ਟੂਲ
Comment[pl]=Narzędzie do skanowania obrazów przy wykorzystaniu płaskiego skanera
Comment[pt]=Uma ferramenta de aquisição de imagens com um 'scanner' plano
Comment[pt_BR]=Uma ferramenta para obter imagens usando um scanner de mesa
Comment[ro]=O unealtă de achiziționat imagini utilizînd un scaner plat
Comment[ru]=Инструмент для получения изображений с помощью сканера
Comment[sk]=Nástroj na získanie obrázkov zo skenera
Comment[sl]=Orodje za pridobivanje slik s pomočjo optičnega bralnika
Comment[sq]=Një mjet për të marrë imazhet duke përdorur një skaner me shtrat të sheshtë
Comment[sv]=Ett verktyg för att hämta bilder med en bildläsare
Comment[th]=เครื่องมือนำเข้ารูปภาพโดยใช้เครื่องสแกนภาพแบบตั้งโต๊ะ
Comment[tr]=Tarayıcı kullanarak resimleri elde etmek için bir araç
Comment[uk]=Інструмент для отримання зображень з планшетних сканерів
Comment[x-test]=xxA tool to acquire images using flat scannerxx
Comment[zh_CN]=一个使用扫描仪捕获图像的工具
Comment[zh_TW]=使用平台式掃描器擷取影像的工具
Icon=scanner
ServiceTypes=KIPI/Plugin
Type=Service
X-KDE-Library=kipiplugin_acquireimages
X-KIPI-PluginCategories=Import
X-KIPI-BinaryVersion=${KIPI_SO_VERSION}
author=Gilles Caulier, caulier dot gilles at gmail dot com
